package system

import (
	"fmt"
	"image/color"

	"code.rocketnine.space/tslocum/commandeuropa/component"
	"code.rocketnine.space/tslocum/commandeuropa/world"
	"code.rocketnine.space/tslocum/gohan"
	"github.com/hajimehoshi/ebiten/v2"
	"github.com/hajimehoshi/ebiten/v2/ebitenutil"
)

type RenderDebug struct {
	Once *component.Once

	op          *ebiten.DrawImageOptions
	debugImg    *ebiten.Image
	initialized bool
}

func (s *RenderDebug) Initialize() {
	s.op = &ebiten.DrawImageOptions{}
	s.op.GeoM.Scale(2, 2)
	s.debugImg = ebiten.NewImage(80, 80)
	s.initialized = true
}

func (s *RenderDebug) Update(_ gohan.Entity) error {
	return gohan.ErrUnregister
}

func (s *RenderDebug) Draw(e gohan.Entity, screen *ebiten.Image) error {
	if world.Debug <= 0 {
		return nil
	}

	if !s.initialized {
		s.Initialize()
	}

	s.debugImg.Fill(color.RGBA{0, 0, 0, 80})
	ebitenutil.DebugPrintAt(s.debugImg, fmt.Sprintf("ENT %d\nUPD %d\nDRA %d\nTPS %0.0f\nFPS %0.0f", gohan.CurrentEntities(), gohan.CurrentUpdates(), gohan.CurrentDraws(), ebiten.CurrentTPS(), ebiten.CurrentFPS()), 2, 0)
	screen.DrawImage(s.debugImg, s.op)
	return nil
}
